#!/bin/sh
####
# EncFS-ROX integration - Open access to an encrypted directory
# Author: James Budiono - Copyright James Budiono 2010
# License: GNU GPL v3 or newer
# Note: close by unmounting the directory
# v0.4 - fix symlink check & refresh rox
####

if [ -z "$1" ]; then
	Xdialog --msgbox "Run this tool from within ROX-Filer." 0 0
	exit
fi

# can't process symlink
if [ "`file \"$1\" | grep \"symbolic link\"`" ]; then
	Xdialog --title "Error" --msgbox "Symbolic link is not supported." 0 0
	exit
fi

# check - encfs exist? no ==> quit
if [ -z "`which encfs`" ]; then
	Xdialog --title "Error" --msgbox "EncFS not found - cannot continue. Please install EncFS first." 0 0
	exit
fi

# 1. prepare all the vars
ENCFS_SIG=".encfs6.xml"  
ENC_DIR_WARN="This directory is encrypted"
ENC_DIR_SIG=".encrypted"
  
ORIG_DIR="$1"
PREFIX="${ORIG_DIR%/*}/"
DIR="${ORIG_DIR##*/}"

ENC_DIR="${PREFIX}.${DIR}"

# checks - are we trying to open an encrypted storage directory?
if [ -f "${ORIG_DIR}/${ENCFS_SIG}" ]; then
	Xdialog --title "Error" --msgbox "This is a storage directory for encrypted files, it cannot be opened." 0 0
	exit
fi

# checks - does storage for encrypted dir exist, with a valid signature? 
if [ ! -f "${ENC_DIR}/${ENCFS_SIG}" ]; then
	Xdialog --title "Error" --msgbox "This directory is not encrypted." 0 0
	exit
fi

# 2. make sure it's not currently mounted (this check is actually unnecessary - Rox guarantees this)
if [ ! -d "${ORIG_DIR}/${ENC_DIR_SIG}" ]; then
	Xdialog --title "Error" --msgbox "${ORIG_DIR} is already opened for access" 0 0
	exit
fi

# 3. Get the password
PASS1=`Xdialog --stdout --title "Open" --password --inputbox "Enter password" 0 0`
if [ -n "$PASS1" ]; then
	
	# 4. Got the password, now mount it
	echo "$PASS1" | encfs --stdin "${ENC_DIR}" "${ORIG_DIR}" -- -o nonempty
	if [ $? -eq 0 ]; then
		rox -x "${PREFIX}"
		Xdialog --title "Success!" --msgbox "Directory ${ORIG_DIR} now opened for access" 0 0 
	else
		Xdialog --title "Error" --msgbox "Unable to open ${ORIG_DIR}, perhaps wrong password?" 0 0 
	fi
else
	Xdialog --title "Cancelled" --msgbox "${ORIG_DIR} not opened for access." 0 0 
fi

